@@ -7,16 +7,17 @@
 # nor does it submit to any jurisdiction.
 #
 
-import os
-import tempfile
-import hashlib
 import datetime
-import sqlite3
+import hashlib
 import json
+import os
+import sqlite3
+import tempfile
+
+from climetlab.utils import bytes_to_string
 from climetlab.utils.html import css
 
 from .settings import SETTINGS
-from climetlab.utils import bytes_to_string
 
 _connection = None
 
@@ -24,7 +25,7 @@ _connection = None
 def connection():
     global _connection
     if _connection is None:
-        cache_dir = SETTINGS.get("cache_directory")
+        cache_dir = SETTINGS.get("cache-directory")
         if not os.path.exists(cache_dir):
             os.mkdir(cache_dir)
         cache_db = os.path.join(cache_dir, "cache.db")
@@ -142,19 +143,13 @@ def update(m, x):
     m.update(str(x).encode("utf-8"))
 
 
-def class_full_name(o):
-    if o.__module__ is None:
-        return o.__name__
-    return o.__module__ + "." + o.__name__
-
-
 def cache_file(owner: str, *args, extension: str = ".cache"):
 
     m = hashlib.sha256()
     update(m, owner)
     update(m, args)
     path = "%s/%s-%s%s" % (
-        SETTINGS.get("cache_directory"),
+        SETTINGS.get("cache-directory"),
         owner.lower(),
         m.hexdigest(),
         extension,
