@@ -8,13 +8,12 @@
 #
 
 import numpy as np
-import xarray as xr
 
 
 class XArrayHelper:
     def __init__(self, data):
 
-        data.climetlab.foo(42)
+        # data.climetlab.foo(42)
 
         self.data = data
         for name, var in data.data_vars.items():
@@ -47,7 +46,9 @@ class XArrayHelper:
 
 
 def helper(data, *args, **kwargs):
+    import xarray as xr
+
     if isinstance(data, xr.Dataset):
         return XArrayHelper(data, *args, **kwargs)
-    else:
-        return XArrayHelper(data.to_dataset(), *args, **kwargs)
+
+    return XArrayHelper(data.to_dataset(), *args, **kwargs)
