@@ -7,18 +7,21 @@
 # nor does it submit to any jurisdiction.
 #
 
-from collections import defaultdict
 import datetime
-from dateutil.parser import parse
+from collections import defaultdict
 
 # datetime.fromisoformat() only available from Python3.7
-from backports.datetime_fromisoformat import MonkeyPatch
+# from backports.datetime_fromisoformat import MonkeyPatch
+from dateutil.parser import parse
 
-MonkeyPatch.patch_fromisoformat()
+# MonkeyPatch.patch_fromisoformat()
 
 
 def parse_date(date):
-    return datetime.datetime.fromisoformat(date)
+    try:
+        return datetime.datetime.fromisoformat(date)
+    except Exception:
+        return parse(date)
 
 
 def to_datetime(dt):
